---
title: Status & Plans 
layout: page 
date: 2014-01-10
---

Status
======

The Urubu software is in the alpha stage of experimental releases.

It is developed with Python3 in mind, but only tested using Python 2.7.

Currently, I develop and test it while migrating the [websites][sites] that I
maintain.

Plans
=====

In the future, some support for tagging and pagination may be added.

I have no plans to add special support for on-site comments. I have become
skeptical of their value, as weak comments consume a lot more (negative) energy
than strong ones. Of course, you can do that yourself in the templates. 

Also, I have no plans to support other input formats, such as reStructuredText
or asciidoc. I work with reStructuredText for manuals, but I don't particularly
like it. Some work was needed on Markdown extensions in order to support my
requirements, and I believe the result is fine now. I don't see much value in
repeating that for other input formats. 

